__title__ = "randfacts"
__description__ = "Package to generate random facts"
__url__ = "https://github.com/TabulateJarl8/randfacts"
__version__ = "0.13.0"
__author__ = "Tabulate"
__author_email__ = "tabulatejarl8@gmail.com"
__license__ = "MIT"
__copyright__ = "Copyright 2020-2021 Connor Sample"
